@@ -66,20 +66,26 @@ convertUSCensusCounties <- function(nameOnly=FALSE) {
   
   # Standardize naming in the SpatialPolygonsDataFrame
   SPDF$countryCode <- 'US'
-  SPDF$countryName <- 'United States'
   SPDF$stateCode <- apply(SPDF@data, 1, extractState, col='Alpha code')
-  SPDF$stateName <- apply(SPDF@data, 1, extractState, col='Name')
   SPDF$countyName <- SPDF$NAME
   
+  # TODO:  Figure out units for ALAND and AWATER and convert to m^2
+  
+  # Guarantee that ALAND and AWATER are numeric
+  SPDF$ALAND <- as.numeric(SPDF$ALAND)
+  SPDF$AWATER <- as.numeric(SPDF$AWATER)
+  
+  # TODO:  COUNTYNS is the polygon uniqueID but what is it?
+  
   # Subset this dataframe to include only obviously useful columns
-  usefulColumns <- c('NAME','ALAND','AWATER','countryCode','countryName','stateCode','stateName',
-                     'countyName','COUNTYFP')
+  usefulColumns <- c('NAME','ALAND','AWATER','countryCode','stateCode',
+                     'countyName','COUNTYFP', 'COUNTYNS')
   SPDF <- SPDF[,usefulColumns]
-  names(SPDF) <- c('name', 'areaLand', 'areaWater', 'countryCode', 'countryName', 
-                   'stateCode', 'stateName', 'countyName', 'countyFIPS')
+  names(SPDF) <- c('name', 'areaLand', 'areaWater', 'countryCode',  
+                   'stateCode',  'countyName', 'countyFIPS', 'COUNTYNS')
   
   # Group polygons with the same identifier (countyName)
-  SPDF <- organizePolygons(SPDF, uniqueID='countyName', sumColumns=c('areaLand','areaWater'))
+  SPDF <- organizePolygons(SPDF, uniqueID='COUNTYNS', sumColumns=c('areaLand','areaWater'))
   
   # Assign a name and save the data
   assign(datasetName,SPDF)
