@@ -9,9 +9,9 @@ testthat::test_that("setSpatialDataDir and getSpatialDataDir work correctly", {
   testthat::expect_equal(getwd(), getSpatialDataDir())
 })
 
-# 'get' function test ----------------------------------------------------------
+# -----------------------------------------------------------------------------
 
-testthat::context("'get' function test")
+testthat::context("get~() functions")
 
 testthat::test_that("get functions handle errors correctly", {
 
@@ -69,6 +69,10 @@ testthat::test_that("getPolygonID handles errors correctly", {
   
 })
 
+# -----------------------------------------------------------------------------
+
+testthat::context("summarizeByPolygon()")
+
 testthat::test_that("summarizeByPolygon properly summarizes", {
   
   testthat::expect_equal(dim(summarizeByPolygon(longitude = c(20.383333, -110, 25.433333, 11.330556, 101.766667, -110, -110),
